summaryrefslogtreecommitdiff
path: root/client/mysqltest.cc
diff options
context:
space:
mode:
authorklemens <ka7@github.com>2017-02-26 16:49:47 +0100
committerSergey Vojtovich <svoj@mariadb.org>2017-03-07 13:38:06 +0400
commit7be541f281225aae8e04bff4210b67688be080bc (patch)
treef6ba5f7862669d13b4c425d44baa7528f42da1d3 /client/mysqltest.cc
parente823023e4bb48b0db9ee91477076fc20db704769 (diff)
downloadmariadb-git-7be541f281225aae8e04bff4210b67688be080bc.tar.gz
spelling fixes
Diffstat (limited to 'client/mysqltest.cc')
-rw-r--r--client/mysqltest.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/client/mysqltest.cc b/client/mysqltest.cc
index afdd2394bc3..2673db0e469 100644
--- a/client/mysqltest.cc
+++ b/client/mysqltest.cc
@@ -2490,7 +2490,7 @@ VAR *var_obtain(const char *name, int len)
/*
- - if variable starts with a $ it is regarded as a local test varable
+ - if variable starts with a $ it is regarded as a local test variable
- if not it is treated as a environment variable, and the corresponding
environment variable will be updated
*/
@@ -3325,7 +3325,7 @@ static int replace(DYNAMIC_STRING *ds_str,
NOTE
Although mysqltest is executed from cygwin shell, the command will be
executed in "cmd.exe". Thus commands like "rm" etc can NOT be used, use
- mysqltest commmand(s) like "remove_file" for that
+ mysqltest command(s) like "remove_file" for that
*/
void do_exec(struct st_command *command)
@@ -6554,7 +6554,7 @@ int read_line(char *buf, int size)
start_lineno));
}
/* Skip all space at begining of line */
skip_char= 1;
}
else if (end_of_query(c))
@@ -6566,10 +6566,10 @@ int read_line(char *buf, int size)
}
else if (c == '}')
{
/* A "}" need to be by itself in the begining of a line to terminate */
*p++= c;
*p= 0;
- DBUG_PRINT("exit", ("Found '}' in begining of a line at line: %d",
+ DBUG_PRINT("exit", ("Found '}' in beginning of a line at line: %d",
cur_file->lineno));
DBUG_RETURN(0);
}
@@ -7931,7 +7931,7 @@ void handle_error(struct st_command *command,
{
/*
The query after a "--require" failed. This is fine as long the server
- returned a valid reponse. Don't allow 2013 or 2006 to trigger an
+ returned a valid response. Don't allow 2013 or 2006 to trigger an
abort_not_supported_test
*/
if (err_errno == CR_SERVER_LOST ||
@@ -9012,7 +9012,7 @@ int main(int argc, char **argv)
var_set_string("MYSQLTEST_FILE", cur_file->file_name);
init_re();
- /* Cursor protcol implies ps protocol */
+ /* Cursor protocol implies ps protocol */
if (cursor_protocol)
ps_protocol= 1;
@@ -9110,7 +9110,7 @@ int main(int argc, char **argv)
abort_on_error);
/*
- some commmands need to be executed or at least parsed unconditionally,
+ some commands need to be executed or at least parsed unconditionally,
because they change the grammar.
*/
ok_to_do= cur_block->ok || command->type == Q_DELIMITER
@@ -9542,7 +9542,7 @@ int main(int argc, char **argv)
die("Test ended with parsing disabled");
/*
- The whole test has been executed _sucessfully_.
+ The whole test has been executed _successfully_.
Time to compare result or save it to record file.
The entire output from test is in the log file
*/
@@ -9588,7 +9588,7 @@ int main(int argc, char **argv)
verbose_msg("Test has succeeded!");
timer_output();
- /* Yes, if we got this far the test has suceeded! Sakila smiles */
+ /* Yes, if we got this far the test has succeeded! Sakila smiles */
cleanup_and_exit(0);
return 0; /* Keep compiler happy too */
}
@@ -10083,7 +10083,7 @@ void free_replace_regex()
buf_len_p - result buffer length. Will change if the buffer is reallocated
pattern - regexp pattern to match
replace - replacement expression
- string - the string to perform substituions in
+ string - the string to perform substitutions in
icase - flag, if set to 1 the match is case insensitive
*/
int reg_replace(char** buf_p, int* buf_len_p, char *pattern,
@@ -6554,7 +6554,7 @@ int read_line(char *buf, int size)
start_lineno));
}
- /* Skip all space at begining of line */
+ /* Skip all space at beginning of line */
skip_char= 1;
}
@@ -6566,10 +6566,10 @@ int read_line(char *buf, int size)
else if (c == '}')
{
- /* A "}" need to be by itself in the begining of a line to terminate */
+ /* A "}" need to be by itself in the beginning of a line to terminate */
*p++= c;
*p= 0;